@@ -1,6 +1,5 @@
-from ..util import config,client,ossclient
+from ..util import config,client,oss_client
 from terminal import green,bold
-from batchcompute.utils.functions import ConfigError
 from .. import const
 
 
@@ -25,9 +24,8 @@ def update_region(region):
         client.check_client(m)
         config.setConfigs(config.COMMON, m)
 
-
-    except ConfigError as e:
-        raise ConfigError('Invalid region %s' % region)
+    except Exception as e:
+        raise Exception('Invalid region %s' % region)
 
 
 def update_osspath(osspath):
@@ -36,12 +34,12 @@ def update_osspath(osspath):
     m['osspath'] = osspath
 
     try:
-        ossclient.check_client(m)
+        oss_client.check_client(m)
         config.setConfigs(config.COMMON, m)
 
 
-    except ConfigError as e:
-        raise ConfigError('Invalid ossPath %s' % (osspath)) if m.get('ossPath') else e
+    except Exception as e:
+        raise Exception('Invalid osspath %s' % (osspath)) if m.get('osspath') else e
 
 
 def update_locale(locale):
@@ -52,8 +50,6 @@ def update_locale(locale):
     m['locale'] = locale
     config.setConfigs(config.COMMON, m)
 
-
-
 def show_config():
     try:
         arr = ['region','accesskeyid','accesskeysecret','osspath','locale']
