@@ -4,6 +4,8 @@
 from ..util import client, oss_client, formater, list2table, result_cache, dag, util
 from terminal import bold, magenta, gray, blue, green, red, yellow, confirm
 from oss2.exceptions import NoSuchKey,NoSuchBucket
+from ..const import CMD
+
 PROGRESS_LEN = 50
 
 
@@ -72,6 +74,8 @@ def list(num,all, state, jobId, jobName):
     if has_more:
         print(gray('\n  append -t <num> to show more, or -a to show all\n'))
 
+    print(gray('  type "%s j <Id|No.>" to show job detail\n' % (CMD)))
+
 def getJobDetail(jobId, descOnly):
     jobId = result_cache.get(jobId, 'jobs')
 
@@ -144,6 +148,8 @@ def getJobDetail(jobId, descOnly):
     list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime', 'Elapse','Cluster'])
 
 
+    print(gray('\n  type "%s j <Id|No.> <TaskName|No.>" to show task detail\n' % CMD))
+
 def getTaskDetail(jobId, taskName):
     jobId = result_cache.get(jobId, 'jobs')
     taskName = result_cache.get(taskName, 'tasks')
@@ -224,7 +230,7 @@ def getTaskDetail(jobId, taskName):
     if c>0:
         print('    '.join(t))
 
-
+    print(gray('\n  type "%s j <Id|No.> <TaskName|No.> <InstanceId>" to show instance detail\n' % CMD))
 
 def getInstanceDetail(jobId, taskName, instanceId):
     jobId = result_cache.get(jobId, 'jobs')
@@ -260,12 +266,15 @@ def getInstanceDetail(jobId, taskName, instanceId):
             if not isinstance(e, NoSuchKey) and not isinstance(e, NoSuchBucket):
                 raise e
 
+    print(gray('\n  If you want to download these logs, type "%s log -h" for more\n' % CMD))
+
 def showLog(osspath, jobId, taskName, instanceId, logType):
 
     osspath = formater.fix_log_path(osspath ,jobId,taskName, instanceId, logType)
     content = oss_client.get_data(osspath)
 
     print('%s' % bold(magenta('Log Content:')))
+    print(magenta('%s%s%s' % ('-'*20, logType, '-'*20)  ))
     if isinstance(content, bytes):
         content = str(content.decode('utf8'))
 
@@ -273,6 +282,7 @@ def showLog(osspath, jobId, taskName, instanceId, logType):
         print(green(content))
     else:
         print(red(content))
+    print(magenta('-'*46))
 
 
 def calc_metric_count(metric):
