@@ -13,7 +13,7 @@ from ..const import IMG_ID,INS_TYPE,CMD
 
 DEFAULT_CLUSTER = "img=%s:type=%s" % (IMG_ID,INS_TYPE)
 
-def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, pack=None, env=None, read_mount={}, write_mount={}, mount=None):
+def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, force=False, pack=None, env=None, read_mount={}, write_mount={}, mount=None):
 
     pre_oss_path = config.get_oss_path()
 
@@ -56,7 +56,8 @@ def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, pack=None, env
     job_desc['DAG']['Tasks']['cli-task']['Parameters']['StdoutRedirectPath'] = '%s%s/logs/' % (pre_oss_path,rand)
     job_desc['DAG']['Tasks']['cli-task']['Parameters']['StderrRedirectPath'] = '%s%s/logs/' % (pre_oss_path,rand)
 
-    #print(job_desc)
+    if force:
+        job_desc['JobFailOnInstanceFail'] = False
 
     result = client.create_job(job_desc)
 
