@@ -95,7 +95,7 @@ cmd_job = Command('job', alias=['j'],
                   description=MSG['job']['description'],
                   usage='''Usage:
 
-    %s job|j [jobId] [taskName] [instanceId] [options]
+    %s job|j [jobId|No.] [taskName|No.] [instanceId] [options]
 
   Examples:
 
@@ -327,7 +327,7 @@ cmd_submit_job = Command('submit', alias=['sub'],
                          usage='''Usage: %s submit|sub <cmd> [option]
 
   Examples:
-      1. %s sub "echo 'hello'"
+      1. %s sub "echo 'hello'" -n 3 -f              # run this cmd on 3 machines(instances) in force mode
       2. %s sub "echo 'hello'" -c img=%s
       3. %s sub "python main.py arg1 arg2" -c cls-xxxx -p ./my_program/
       4. %s sub "python /home/admin/test/main.py" -m oss://your-bucket/a/b/:/home/admin/test/''' % (
@@ -342,6 +342,8 @@ cmd_submit_job.option("-t, --timeout [seconds]",
 cmd_submit_job.option("-n, --nodes [machine_number]",
                        MSG['submit']['option']['nodes'],
                       resolve=job_submit.trans_nodes)
+cmd_submit_job.option("-f, --force",
+                      MSG['submit']['option']['force'])
 cmd_submit_job.option("-e, --env [kv_pairs]",
                       MSG['submit']['option']['env'],
                       resolve=job_submit.trans_env)
