@@ -1,6 +1,6 @@
 
 from .externals.command import Command
-from .action import project_create,project_build,project_submit,project_status,project_update
+from .action import project_create,project_build,project_submit,project_status,project_update,project_task_add
 from . import const,i18n_util
 
 COMMAND = const.COMMAND
@@ -88,28 +88,27 @@ def init(cmd_project):
     cmd_project.action(cmd_project_update)
 
 
-    #
-    # # add task
-    # cmd_add_task = Command('add_task', alias=['at'], description='add a task',
-    #                        detail="add a task node into job.json, and create a promgram file in src folder.(%s)" % ( RUN_IN_PROJECT_FOLDER),
-    #                        usage="""Usage: %s add_task|at [task_name] [option]
+
+    # add task
+    # cmd_add_task = Command('add_task', alias=['at'],
+    #                         arguments=['task','cmdline'],
+    #                        description=MSG['project']['add_task']['description'],
+    #                        detail=MSG['project']['add_task']['detail'],
+    #                        usage="""Usage: %s project|p add_task|at <task_name> [option]
     #
     #   Examples:
-    #       1. %s at Map                                          #add a task named Map
-    #       2. %s at Map -d localhost:5000/myubuntu               #add a task named Map, use docker, you should tag you image using prefix:'localhost:5000/' first. if you forgot the port, type "docker ps" to see item named: registry_oss
-    #       3. %s at Map -i img-00000000561CB0FE000061CC00000411  #add a task named Map, and set image id
-    #       4. %s at Map -o oss://my-bucket/my-key/               # set oss oss_path""" % (COMMAND, CMD, CMD, CMD, CMD),
-    #                        arguments=['task_name'],
-    #                        func=add_task.add)
-    # cmd_add_task.option('-i, --image_id [image_id]', 'set image_id for task, type "%s img" for more' % CMD,
-    #                     resolve=update_task.transform_image_id)
-    # cmd_add_task.option('-d, --docker_image [docker_image_name]', 'use docker image, type "docker images" for more')
-    # cmd_add_task.option('-o, --oss_path [oss_path]', 'set oss path, and it will set value of PackageUri,StdoutRedirectPath and StderrRedirectPath',
-    #                       resolve=update_task.transform_oss_path)
-    # program.action(cmd_add_task)
-    #
-    #
+    #       1. %s p at Map 'python map.py'                          # add a task named Map
+    #       2. %s p at Map 'python map.py' -d localhost:5000/myubuntu               # add a task named Map, use docker image
+    #       3. %s p at Map 'python map.py' -c img=%s:type=ecs.s3.large     # set Auto Cluster
+    #       4. %s p at Map 'python map.py' -c cls-000010102                         # use Cluster Id""" % (COMMAND, CMD, CMD,CMD,IMG_ID, CMD),
     #
+    #                        func=project_task_add.add_task)
+    # cmd_add_task.option('-d, --docker [docker_image]', MSG['project']['add_task']['option']['docker'])
+    # cmd_add_task.option("-c, --cluster [cluster]", MSG['project']['add_task']['option']['cluster'])
+    # cmd_project.action(cmd_add_task)
+
+
+
     # # remove task
     # cmd_remove_task = Command('rm_task', alias=['rt'], description='remove a task',
     #                           detail="remove tasks from job.json, and remove the promgram files from src folder. multiple task_name should seperated by ','.(%s)" % (RUN_IN_PROJECT_FOLDER),
